import argparse
from metadocker.cmdline.commands.specific import start, stop, build, run, \
    rm, status, logs, systemd, shell
from metadocker.cmdline.commands.main import init, list
import sys


class Args(argparse.ArgumentParser):
    _COMMANDS = []


    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.subparsers = self.add_subparsers(prog="action", parser_class=argparse.ArgumentParser)
        self.add_argument("--debug", "-d", help="Mode débug", action="store_true")
        for k in self._COMMANDS:
            self._add_command(k)

    def parse(self, env, args=None):
        args = args if args is not None else (sys.argv[1:])

        ret = self.parse_args(args)
        if hasattr(ret, "command"):
            if env is not None:
                ret.command(ret).start(env)
            else:
                ret.command(ret).start()

        else:
            self.print_help()
            exit(-1)
        return ret

    def _add_command(self, classe):
        kwargs = {}
        if classe.HELP:
            kwargs["help"] = classe.HELP
        if classe.ALIASES:
            kwargs["aliases"] = classe.ALIASES

        parser = self.subparsers.add_parser(classe.NAME, **kwargs)
        for k in classe.ARGUMENTS:
            k.call(parser)
        parser.set_defaults(command=classe)
        return parser

    @classmethod
    def main(cls, env=None, args=None):
        return cls().parse(env, args)


class ArgsFromFile(Args):
    _COMMANDS = [build.BuildCommand, start.StartCommand, stop.StopCommand, run.RunCommand,
                 rm.RmCommand, status.StatusCommand, logs.LogsCommand, systemd.SystemdCommand,
                 shell.ShellCommand]

    def __init__(self):
        super().__init__()

class MainArgs(Args):
    _COMMANDS = [init.InitCommand, list.ListCommand]

    def __init__(self):
        super().__init__()