import sys
from pathlib import Path

from metadocker.cmdline.commands.base import Argument, Command
from metadocker.register import load_env


class InitCommand(Command):
    NAME = "init"
    HELP = "Initialise un script"
    ARGUMENTS = [
        Argument("env", help="Le type d'environnement à initialiser"),
        Argument("--output", "-o", action="store_true", help="Le fichier destination", default="./docker")
    ]

    def run(self):
        env_name = self.env.lower()
        envs = load_env()
        if env_name not in envs:
            print(f"Impossible de trouver l'environnement '{self.env}'", file=sys.stderr)
            exit(-1)

        output = Path(self.output)
        output.parent.mkdir(exist_ok=True, parents=True)
        env = envs[env_name]()

        content = env.create_empty_config()
        output.write_text(content)
        output.chmod(0o750)

