import subprocess
from pathlib import Path

from metadocker.cmdline.commands.base import SpecificCommand, Argument
from metadocker.docker import DockerBuilder


def get_file_content(name, time=10):
    return f"""[Unit]
Description=Le docker {name}
Requires=docker.service
After=docker.service

[Service]
Restart=always
ExecStart=/usr/bin/docker start -a {name}
ExecStop=/usr/bin/docker stop -t {time} {name}

[Install]
WantedBy=multi-user.target

"""

class SystemdCommand(SpecificCommand):
    NAME = "systemd"
    HELP = "Permet de gérer le démarrage automatique"
    ARGUMENTS = [
        Argument("--output", "-o", help="Fichier de sortie de la génération"),
        Argument("--install", "-i", action="store_true", help="Install le docker dans systemd"),
        Argument("--startup", "-s", action="store_true", help="Temps avent de forcer le container"),

    ]
    def run(self, env):
        name = env.docker.name
        level = 0
        if self.startup:
            level = 2
        elif self.install:
            level = 1

        output = (Path(self.output or env.root) / f"{name}.service").resolve()
        output.parent.mkdir(exist_ok=True, parents=True)
        output.write_text(get_file_content(name))

        if level >= 1:
            subprocess.run(["sudo", "cp", output, "/etc/systemd/system/"])

        if level >= 2:
            subprocess.run(["sudo", "systemctl", "enable", f"{name}.service"])
