import json


class DockerBuilder:

    def __init__(self, project, version, tag=None, name=None):
        self.docker_file = []
        self.systemd_file = []
        self.project = project
        self.version = version
        self.tag = tag
        if tag is None:
            if self.version:
                self.tag = f"{self.project.lower()}-{self.version.lower()}"
            else:
                self.tag = f"{self.project.lower()}-latest"
        self.name = name if tag else f"{self.project.lower()}"

    def get_file_content(self):
        return "\n".join(self.docker_file)

    def add(self, *args):
        self.docker_file.append(" ".join([str(x) for x in args if x is not None]))

    def run(self, *args):
        self.add("RUN", *args)

    def from_(self, image, name = None):
        self.add("FROM", image, f"as {name}" if name else None)

    def copy(self,src, dst):
        self.add("COPY", src, dst)

    def cmd(self, *args):
        self.add("CMD", *args)

    def workdir(self, path):
        self.add("WORKDIR", path)

    def user(self, user):
        self.add("USER", user)


    def env(self, *args):
        self.add("ENV", *args)

    def arg(self, k, v):
        self.add("ARG", k, v)

    def expose(self, port):
        self.add("EXPOSE", port)

    def volume(self, *args):
        self.add("VOLUME", *args)

    def meta(self, data):
        data = json.dumps(dict(data.items()))
        self.add(f"# meta={data}")